Index: chrome/browser/tab_contents/tab_contents.cc |
diff --git a/chrome/browser/tab_contents/tab_contents.cc b/chrome/browser/tab_contents/tab_contents.cc |
index 1d702bd78ae465c94d40eed541af3c0ef99f9b3b..2c6b9389a1646102035e39981980bd0eefd8b184 100644 |
--- a/chrome/browser/tab_contents/tab_contents.cc |
+++ b/chrome/browser/tab_contents/tab_contents.cc |
@@ -2875,11 +2875,12 @@ WebPreferences TabContents::GetWebkitPrefs() { |
WebPreferences web_prefs = |
RenderViewHostDelegateHelper::GetWebkitPrefs(profile, is_dom_ui); |
// Force accelerated compositing off for chrome: and chrome-extension: |
// pages. |
if (GetURL().SchemeIs(chrome::kChromeUIScheme) || |
GetURL().SchemeIs(chrome::kExtensionScheme)) { |
web_prefs.accelerated_compositing_enabled = false; |
+ web_prefs.accelerated_2d_canvas_enabled = false; |
} |
#if defined(OS_MACOSX) |
@@ -2875,11 +2875,12 @@ WebPreferences TabContents::GetWebkitPrefs() { |
WebPreferences web_prefs = |
RenderViewHostDelegateHelper::GetWebkitPrefs(profile, is_dom_ui); |
- // Force accelerated compositing off for chrome: and chrome-extension: |
- // pages. |
+ // Force accelerated compositing and 2d canvas off for chrome: and |
+ // chrome-extension: pages. |
if (GetURL().SchemeIs(chrome::kChromeUIScheme) || |
GetURL().SchemeIs(chrome::kExtensionScheme)) { |